The `court-scraper` package provides a Python library and command-line tool that help search and download case information from county courts in the United States.

Learn more or reach out using the below resources:

- Gitter for chat: https://gitter.im/court-scraper/general
- Documentation: http://court-scraper.readthedocs.io/en/latest/
- GitHub: https://github.com/biglocalnews/court-scraper
- PyPI: https://pypi.python.org/pypi/court-scraper
